@@ -13,8 +13,8 @@
 
 #include "cogl-enum-types.h"
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/deprecated/cogl-material-compat.h" */
-#include "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/deprecated/cogl-material-compat.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-material-compat.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-material-compat.h"
 
 GType
 cogl_material_filter_get_type (void)
@@ -115,8 +115,8 @@ cogl_material_layer_type_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/deprecated/cogl-shader.h" */
-#include "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/deprecated/cogl-shader.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-shader.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-shader.h"
 
 GType
 cogl_shader_type_get_type (void)
@@ -141,8 +141,8 @@ cogl_shader_type_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/cogl-bitmap.h" */
-#include "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/cogl-bitmap.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-bitmap.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-bitmap.h"
 
 GType
 cogl_bitmap_error_get_type (void)
@@ -168,8 +168,8 @@ cogl_bitmap_error_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/cogl-texture.h" */
-#include "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/cogl-texture.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-texture.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-texture.h"
 
 GType
 cogl_texture_error_get_type (void)
@@ -244,8 +244,8 @@ cogl_texture_components_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/cogl-types.h" */
-#include "/usr/src/ports/cogl/cogl-1.18.2-1.i686/src/cogl-1.18.2/cogl/cogl-types.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-types.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-types.h"
 
 GType
 cogl_pixel_format_get_type (void)
@@ -706,6 +706,29 @@ cogl_read_pixels_flags_get_type (void)
 
   return g_enum_type_id__volatile;
 }
+GType
+cogl_stereo_mode_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { COGL_STEREO_BOTH, "COGL_STEREO_BOTH", "both" },
+        { COGL_STEREO_LEFT, "COGL_STEREO_LEFT", "left" },
+        { COGL_STEREO_RIGHT, "COGL_STEREO_RIGHT", "right" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("CoglStereoMode"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
 
 /* Generated data ends here */
 
